@@ -14,6 +14,7 @@ import pygeoj
 import requests
 from bs4 import BeautifulSoup
 from natsort import natsorted
+from tabulate import tabulate
 from tqdm import tqdm
 
 
@@ -52,7 +53,7 @@ def appeears_version():
             + "========================================================================="
         )
         print(
-            "Current version of pyaqua is {} upgrade to lastest version: {}".format(
+            "Current version of appeears is {} upgrade to lastest version: {}".format(
                 pkg_resources.get_distribution("appeears").version,
                 company.string.strip().split(" ")[-1],
             )
@@ -104,11 +105,12 @@ def humansize(nbytes):
 # set credentials
 def auth():
     home = expanduser("~/appeears.json")
-    usr = input("Enter email: ")
+    usr = input("Enter username: ")
     pwd = getpass.getpass("Enter password: ")
     data = {"username": usr, "password": pwd}
     with open(home, "w") as outfile:
         json.dump(data, outfile)
+    print('Authentication credentials saved')
 
 
 def auth_from_parser(args):
@@ -134,7 +136,7 @@ def tokenizer():
     )
     if response.status_code in error_codes.keys():
         print(error_codes.get(response.status_code))
-        sys.exit(response.json()['message'])
+        sys.exit(response.json()["message"])
     token_response = response.json()
     return token_response["token"]
 
@@ -145,7 +147,7 @@ def products(keyword):
         "https://appeears.earthdatacloud.nasa.gov/api/product")
     if response.status_code in error_codes.keys():
         print(error_codes.get(response.status_code))
-        sys.exit(response.json()['message'])
+        sys.exit(response.json()["message"])
     product_response = response.json()
     products = {p["ProductAndVersion"]: p for p in product_response}
     if keyword is not None:
@@ -176,10 +178,20 @@ def layers(pid):
     )
     if response.status_code in error_codes.keys():
         print(error_codes.get(response.status_code))
-        sys.exit(response.json()['message'])
+        sys.exit(response.json()["message"])
     layer_response = response.json()
+    print(f'Layers for product id {pid}'+'\n')
+    layer_list = []
+    i = 1
     for layer in layer_response:
-        print(layer)
+        lyr = {
+            "Index": i,
+            "Layer": layer
+        }
+        layer_list.append(lyr)
+        i = i+1
+    print(tabulate(layer_list, headers="keys", tablefmt="heavy_grid"))
+    # print(layer)
 
 
 def layers_from_parser(args):
@@ -189,7 +201,7 @@ def layers_from_parser(args):
 # get spatial projection info
 def spatial():
     response = requests.get(
-        'https://appeears.earthdatacloud.nasa.gov/api/spatial/proj')
+        "https://appeears.earthdatacloud.nasa.gov/api/spatial/proj")
     proj_response = response.json()
     print(json.dumps(proj_response, indent=2))
 
@@ -200,29 +212,29 @@ def spatial_from_parser(args):
 
 # submit a task task_payload
 payload = {
-    'task_type': '',
-    'task_name': '',
-    'params': {
-        'layers': '',
-        'output': {
-            'format': {
-                'type': 'geotiff',
+    "task_type": "",
+    "task_name": "",
+    "params": {
+        "layers": "",
+        "output": {
+            "format": {
+                "type": "geotiff",
             },
-            'projection': 'geographic'
+            "projection": "geographic",
         },
-        'dates': [
+        "dates": [
             {
-                'startDate': '',
-                'endDate': '',
-                'recurring': False,
-                'yearRange': [
+                "startDate": "",
+                "endDate": "",
+                "recurring": False,
+                "yearRange": [
                     1950,
                     2050,
                 ],
             },
         ],
-        'coordinates': ''
-    }
+        "coordinates": "",
+    },
 }
 
 
@@ -236,32 +248,34 @@ def tasksubmit(**kwargs):
             testfile = pygeoj.load(value)
             coordinates = []
             for feature in testfile:
-                if feature.geometry.type == 'Point':
+                if feature.geometry.type == "Point":
                     payload["task_type"] = "point"
                     lat_long_dict = {
                         "latitude": feature.geometry.coordinates[1],
-                        "longitude": feature.geometry.coordinates[0]
+                        "longitude": feature.geometry.coordinates[0],
                     }
                     coordinates.append(lat_long_dict)
-                    payload['params']['coordinates'] = coordinates
-                elif feature.geometry.type == 'Polygon':
+                    payload["params"]["coordinates"] = coordinates
+                elif feature.geometry.type == "Polygon":
                     payload["task_type"] = "area"
-                    geom = {"geo": {
-                        'type': 'FeatureCollection',
-                                'features': [
-                                    {
-                                        'type': 'Feature',
-                                        'properties': {},
-                                        'geometry': {
-                                            'type': 'Polygon',
-                                            'coordinates': feature.geometry.coordinates
-                                        },
+                    geom = {
+                        "geo": {
+                            "type": "FeatureCollection",
+                            "features": [
+                                {
+                                    "type": "Feature",
+                                    "properties": {},
+                                    "geometry": {
+                                        "type": "Polygon",
+                                        "coordinates": feature.geometry.coordinates,
                                     },
-                                ]
-                    }, }
+                                },
+                            ],
+                        },
+                    }
                     coordinates = feature.geometry.coordinates
-                    payload['params'].pop('coordinates')
-                    payload['params'].update(geom)
+                    payload["params"].pop("coordinates")
+                    payload["params"].update(geom)
                 else:
                     sys.exit("Unknown geometry type")
 
@@ -275,6 +289,8 @@ def tasksubmit(**kwargs):
             payload["params"]["dates"][0]["endDate"] = str(value)
         if key == "recurring":
             payload["params"]["dates"][0]["recurring"] = bool(value)
+        if key == "projection":
+            payload["params"]["output"]["projection"] = str(value)
         if key == "product":
             response = requests.get(
                 f"https://appeears.earthdatacloud.nasa.gov/api/product/{value}"
@@ -282,39 +298,56 @@ def tasksubmit(**kwargs):
             layer_response = response.json()
             layer_list = []
             for layer in layer_response:
-                layer_json = {
-                    "layer": layer,
-                    "product": value
-                }
+                layer_json = {"layer": layer, "product": value}
                 layer_list.append(layer_json)
             payload["params"]["layers"] = layer_list
+        if key == 'index' and value is not None:
+            index_list = [x-1 for x in value]
+            l_index = []
+            for i in index_list:
+                l_index.append(payload["params"]["layers"][i])
+            if len(l_index) != 0:
+                payload["params"]["layers"] = l_index
+
     #print(json.dumps(payload, indent=2))
 
     response = requests.post(
-        'https://appeears.earthdatacloud.nasa.gov/api/task', headers={"Authorization": f"Bearer {token}"}, json=payload)
+        "https://appeears.earthdatacloud.nasa.gov/api/task",
+        headers={"Authorization": f"Bearer {token}"},
+        json=payload,
+    )
     if response.status_code in error_codes.keys():
         print(error_codes.get(response.status_code))
-        sys.exit(response.json()['message'])
+        sys.exit(response.json()["message"])
     else:
         print(f"Submitted task with task ID {response.json()['task_id']}")
 
 
 def tasksubmit_from_parser(args):
-    tasksubmit(name=args.name, product=args.product, start=args.start,
-               end=args.end, recurring=args.recurring, input=args.geometry)
+    tasksubmit(
+        name=args.name,
+        product=args.product,
+        start=args.start,
+        end=args.end,
+        recurring=args.recurring,
+        projection=args.projection,
+        index=args.index,
+        input=args.geometry,
+    )
 
 
 # delete task using task id
 def delete(tid):
     token = tokenizer()
     response = requests.delete(
-        f'https://appeears.earthdatacloud.nasa.gov/api/task/{tid}',
-        headers={"Authorization": f"Bearer {token}"})
+        f"https://appeears.earthdatacloud.nasa.gov/api/task/{tid}",
+        headers={"Authorization": f"Bearer {token}"},
+    )
     if response.status_code in error_codes.keys():
         print(error_codes.get(response.status_code))
-        sys.exit(response.json()['message'])
+        sys.exit(response.json()["message"])
     elif response.status_code == 204:
-        print(f'Task with task id {tid} deleted')
+        print(f"Task with task id {tid} deleted")
 
 
 def delete_from_parser(args):
@@ -330,7 +363,7 @@ def task_all(status):
     )
     if response.status_code in error_codes.keys():
         print(error_codes.get(response.status_code))
-        sys.exit(response.json()['message'])
+        sys.exit(response.json()["message"])
     status_response = response.json()
     if len(status_response) != 0:
         task_list = []
@@ -387,7 +420,7 @@ def task_status(tid, status):
         )
         if response.status_code in error_codes.keys():
             print(error_codes.get(response.status_code))
-            sys.exit(response.json()['message'])
+            sys.exit(response.json()["message"])
         if response.status_code == 200:
             status_response = response.json()
             if (
@@ -402,7 +435,7 @@ def task_status(tid, status):
                 )
                 if response.status_code in error_codes.keys():
                     print(error_codes.get(response.status_code))
-                    sys.exit(response.json()['message'])
+                    sys.exit(response.json()["message"])
                 task_response = response.json()
                 if len(task_response) != 0:
                     for task in task_response:
@@ -437,7 +470,7 @@ def task_status(tid, status):
                         )
                         if response.status_code in error_codes.keys():
                             print(error_codes.get(response.status_code))
-                            sys.exit(response.json()['message'])
+                            sys.exit(response.json()["message"])
                         task_json = response.json()
                         for key, value in task_json.items():
                             if key == "progress":
@@ -464,7 +497,7 @@ def file_bundle(tid):
     )
     if response.status_code in error_codes.keys():
         print(error_codes.get(response.status_code))
-        sys.exit(response.json()['message'])
+        sys.exit(response.json()["message"])
     bundle_response = response.json()
     file_size_total = []
     file_id_list = []
@@ -488,7 +521,7 @@ def download_task(tid, dest_dir):
     )
     if response.status_code in error_codes.keys():
         print(error_codes.get(response.status_code))
-        sys.exit(response.json()['message'])
+        sys.exit(response.json()["message"])
     if response.status_code == 200:
         if "status" in response.json().keys():
             file_id_list = file_bundle(tid)
@@ -562,18 +595,17 @@ def main(args=None):
     parser_spatial.set_defaults(func=spatial_from_parser)
 
     parser_tasksubmit = subparsers.add_parser(
-        "task-submit", help="Submit your task"
-    )
+        "task-submit", help="Submit your task")
     required_named = parser_tasksubmit.add_argument_group(
         "Required named arguments.")
-    required_named.add_argument(
-        "--name", help="Task name", required=True
-    )
+    required_named.add_argument("--name", help="Task name", required=True)
     required_named.add_argument(
         "--product", help="Product ID returned from product tool", required=True
     )
     required_named.add_argument(
-        "--geometry", help="Full path to geometry.geojson file point or single polygon", required=True
+        "--geometry",
+        help="Full path to geometry.geojson file point or single polygon",
+        required=True,
     )
     required_named.add_argument(
         "--start", help="Start date in format YYYY-MM-DD", required=True
@@ -583,6 +615,14 @@ def main(args=None):
     )
     optional_named = parser_tasksubmit.add_argument_group(
         "Optional named arguments")
+
+    nargs = '+'
+    optional_named.add_argument(
+        "--index", help="space separated index of layers for task", nargs='+', type=int, default=None
+    )
+    optional_named.add_argument(
+        "--projection", help="Spatial projection", default="geographic"
+    )
     optional_named.add_argument(
         "--recurring", help="Date range recurring True|False", default=False
     )
